@@ -19,12 +19,6 @@
 #'   if neither is given, then the dose is assumed to be a bolus 
 #'   (\code{duration=0}).  If \code{rate} is given, then the dose amount
 #'   must be given (the left hand side of the \code{formula}).
-#' @param labels (optional) Labels for use when plotting.  They are a 
-#'   named list where the names correspond to the names in the data 
-#'   frame and the values are used for xlab and/or ylab as appropriate.
-#' @param units (optional) Units for use when plotting and calculating 
-#'   parameters.  Note that unit conversions and simplifications are not
-#'   done; the text is used as-is.
 #' @param time.nominal (optional) The name of the nominal time column
 #'   (if the main time variable is actual time.  The \code{time.nominal}
 #'   is not used during calculations; it is available to assist with
@@ -66,7 +60,11 @@ PKNCAdose.tbl_df <- function(data, ...)
 #' @rdname PKNCAdose
 #' @export
 PKNCAdose.data.frame <- function(data, formula, route, rate, duration,
-                                 labels, units, time.nominal, exclude, ...) {
+                                 time.nominal, exclude, ...) {
+  ## The data must have... data
+  if (nrow(data) == 0) {
+    stop("data must have at least one row.")
+  }
   ## Check inputs
   if (!missing(time.nominal)) {
     if (!(time.nominal %in% names(data))) {
@@ -111,11 +109,6 @@ PKNCAdose.data.frame <- function(data, formula, route, rate, duration,
   if (any(mask.indep) & !all(mask.indep)) {
     stop("Some but not all values are missing for the independent variable, please see the help for PKNCAdose for how to specify the formula and confirm that your data has dose times for all doses.")
   }
-  ## check and add labels and units
-  if (!missing(labels))
-    ret <- set.name.matching(ret, "labels", labels, data)
-  if (!missing(units))
-    ret <- set.name.matching(ret, "units", units, data)
   if (missing(route)) {
     ret <- setRoute.PKNCAdose(ret)
   } else {
@@ -124,7 +117,10 @@ PKNCAdose.data.frame <- function(data, formula, route, rate, duration,
   ret <- setDuration.PKNCAdose(ret, duration=duration,
                                rate=rate, dose=getDepVar.PKNCAdose(ret))
   if (!missing(time.nominal)) {
-    ret$time.nominal <- time.nominal
+    ret <-
+      setAttributeColumn(object=ret,
+                         attr_name="time.nominal",
+                         col_name=time.nominal)
   }
   ret
 }
@@ -146,14 +142,19 @@ setRoute <- function(object, ...)
 #' @export
 setRoute.PKNCAdose <- function(object, route, ...) {
   if (missing(route)) {
-    message("Assuming route of administration is extravascular")
-    tmpval <- getColumnValueOrNot(object$data, "extravascular", "route")
+    object <-
+      setAttributeColumn(object=object,
+                         attr_name="route",
+                         default_value="extravascular",
+                         message_if_default="Assuming route of administration is extravascular")
   } else {
-    tmpval <- getColumnValueOrNot(object$data, route, "route")
+    object <-
+      setAttributeColumn(object=object,
+                         attr_name="route",
+                         col_or_value=route)
   }
-  object$data <- tmpval$data
-  object$route <- tmpval$name
-  if (!all(tolower(object$data[[object$route]]) %in% c("extravascular", "intravascular"))) {
+  if (!all(tolower(getAttributeColumn(object=object, attr_name="route")[[1]]) %in%
+           c("extravascular", "intravascular"))) {
     stop("route must have values of either 'extravascular' or 'intravascular'.  Please set to one of those values and retry.")
   }
   object
@@ -175,27 +176,27 @@ setDuration <- function(object, ...)
 #' @export
 setDuration.PKNCAdose <- function(object, duration, rate, dose, ...) {
   if (missing(duration) & missing(rate)) {
-    message("Assuming instant dosing (duration=0)")
-    tmpval <- getColumnValueOrNot(object$data, 0, "duration")
+    object <- setAttributeColumn(object=object, attr_name="duration", default_value=0,
+                                 message_if_default="Assuming instant dosing (duration=0)")
+                                
   } else if (!missing(duration) & !missing(rate)) {
     stop("Both duration and rate cannot be given at the same time")
     # TODO: A consistency check could be done, but that would get into
     # requiring near-equal checks for floating point error.
   } else if (!missing(duration)) {
-    tmpval <- getColumnValueOrNot(object$data, duration, "duration")
+    object <- setAttributeColumn(object=object, attr_name="duration", col_or_value=duration)
   } else if (!missing(rate) & !missing(dose)) {
     tmprate <- getColumnValueOrNot(object$data, rate, "rate")
     tmpdose <- getColumnValueOrNot(object$data, dose, "dose")
     duration <- tmpdose$data[[tmpdose$name]]/tmprate$data[[tmprate$name]]
-    tmpval <- getColumnValueOrNot(object$data, duration, "duration")
+    object <- setAttributeColumn(object=object, attr_name="duration", col_or_value=duration)
   }
-  duration.val <- tmpval$data[[tmpval$name]]
+  duration.val <- getAttributeColumn(object=object, attr_name="duration")[[1]]
   if (is.numeric(duration.val) &&
       !any(is.na(duration.val)) &&
       !any(is.infinite(duration.val)) &&
       all(duration.val >= 0)) {
-    object$data <- tmpval$data
-    object$duration <- tmpval$name
+    # It passes
   } else {
     stop("duration must be numeric without missing (NA) or infinite values, and all values must be >= 0")
   }
@@ -249,42 +250,44 @@ getGroups.PKNCAdose <- function(...) {
 getData.PKNCAdose <-  function(object)
   object$data
 
+#' @rdname getDataName
+getDataName.PKNCAdose <- function(object)
+  "data"
+
 #' @rdname print.PKNCAconc
 #' @export
 print.PKNCAdose <- function(x, n=6, summarize=FALSE, ...) {
   cat("Formula for dosing:\n ")
   print(stats::formula(x), showEnv=FALSE, ...)
+  if (!is.null(time_nom_data <- getAttributeColumn(x, attr_name="time.nominal", warn_missing=c()))) {
+    cat("Nominal time column is: ", names(time_nom_data), "\n", sep="")
+  } else {
+    cat("Nominal time column is not specified.\n")
+  }
   if (summarize) {
     cat("\n")
-    grp <- getGroups(x)
+    grp <- getGroups.PKNCAdose(x)
     if (ncol(grp) > 0) {
-      tmp.summary <- data.frame(Group.Name=names(grp),
-                                Count=0)
-      for (i in 1:ncol(grp))
-        tmp.summary$Count[i] <- nrow(unique(grp[,1:i,drop=FALSE]))
-      cat("Group summary:\n")
-      names(tmp.summary) <- gsub("\\.", " ", names(tmp.summary))
+      tmp.summary <- as.data.frame(
+        lapply(grp, FUN=function(y) length(unique(y))))
+      cat("Number unique entries in each group:\n")
       print.data.frame(tmp.summary, row.names=FALSE)
     } else {
       cat("No groups.\n")
     }
-  }
-  if ("time.nominal" %in% names(x)) {
-    cat("Nominal time column is: ", x$time.nominal, "\n", sep="")
   } else {
-    cat("Nominal time column is not specified.\n")
-  }
-  if (n != 0) {
-    if (n >= nrow(x$data)) {
-      cat("\nData for dosing:\n")
-    } else if (n < 0) {
-      cat(sprintf("\nFirst %d rows of dosing data:\n",
-                  nrow(x$data)+n))
-    } else {
-      cat(sprintf("\nFirst %d rows of dosing data:\n",
-                  n))
+    if (n != 0) {
+      if (n >= nrow(x$data)) {
+        cat("\nData for dosing:\n")
+      } else if (n < 0) {
+        cat(sprintf("\nFirst %d rows of dosing data:\n",
+                    nrow(x$data)+n))
+      } else {
+        cat(sprintf("\nFirst %d rows of dosing data:\n",
+                    n))
+      }
+      print.data.frame(utils::head(x$data, n=n), ..., row.names=FALSE)
     }
-    print.data.frame(utils::head(x$data, n=n), ..., row.names=FALSE)
   }
 }
 
