@@ -126,7 +126,7 @@ test_that("pk.calc.clast.obs", {
   expect_equal(pk.calc.clast.obs(c1, t1), NA)
 })
 
-test_that("pk.calc.thalf.eff and its wrappers", {
+test_that("pk.calc.thalf.eff", {
   ## No input gives equivalent no output
   expect_equal(pk.calc.thalf.eff(c()),
                numeric())
@@ -140,16 +140,9 @@ test_that("pk.calc.thalf.eff and its wrappers", {
   r1 <- log(2)*d1
   expect_equal(pk.calc.thalf.eff(d1),
                r1)
-  
-  expect_equal(pk.calc.thalf.eff.obs(d1),
-               pk.calc.thalf.eff(d1),
-               info="pk.calc.thalf.eff.obs is a simple wrapper around pk.calc.thalf.eff")
-  expect_equal(pk.calc.thalf.eff.pred(d1),
-               pk.calc.thalf.eff(d1),
-               info="pk.calc.thalf.eff.pred is a simple wrapper around pk.calc.thalf.eff")
 })
 
-test_that("pk.calc.kel and its wrappers", {
+test_that("pk.calc.kel", {
   ## No input gives equivalent no output
   expect_equal(pk.calc.kel(c()),
                numeric())
@@ -162,79 +155,113 @@ test_that("pk.calc.kel and its wrappers", {
   d1 <- c(0, 1, NA, 3)
   r1 <- 1/d1
   expect_equal(pk.calc.kel(d1), r1)
-  
-  expect_equal(pk.calc.kel.obs(d1),
-               pk.calc.kel(d1),
-               info="pk.calc.kel.obs is a simple wrapper around pk.calc.kel")
-  expect_equal(pk.calc.kel.pred(d1),
-               pk.calc.kel(d1),
-               info="pk.calc.kel.pred is a simple wrapper around pk.calc.kel")
 })
 
-test_that("pk.calc.cl and its wrappers", {
+test_that("pk.calc.cl", {
   ## Ensure that dose and auc are required
-  expect_error(pk.calc.cl(aucinf=NA),
+  expect_error(pk.calc.cl(auc=NA),
                info="dose is required for clearance calculation")
   expect_error(pk.calc.cl(dose=NA),
-               info="aucinf is required for clearance calculation")
+               info="auc is required for clearance calculation")
 
-  expect_equal(pk.calc.cl(dose=10, aucinf=100), 0.1,
-               info="Normal clearance calcualtion works")
-  expect_equal(pk.calc.cl(dose=c(10, 10, 10), aucinf=c(10, NA, 100)),
+  expect_equal(pk.calc.cl(dose=10, auc=100), 0.1,
+               info="Normal clearance calculation works")
+  expect_equal(pk.calc.cl(dose=c(10, 10, 10), auc=c(10, NA, 100)),
                c(1, NA, 0.1),
-               info="Vectors for both dose and aucinf give vectors for clearance (with NAs)")
-  expect_equal(pk.calc.cl(dose=c(50, 50), aucinf=100),
+               info="Vectors for both dose and auc give vectors for clearance (with NAs)")
+  expect_equal(pk.calc.cl(dose=c(50, 50), auc=100),
                1,
-               info="Vector for dose and scalar for aucinf scalar output with the sum of doses")
-  
-  expect_equal(pk.calc.cl.last(dose=10, auclast=100),
-               pk.calc.cl(dose=10, aucinf=100),
-               info="pk.calc.cl.last is a simple wrapper around pk.calc.cl")
-  expect_equal(pk.calc.cl.all(dose=10, aucall=100),
-               pk.calc.cl(dose=10, aucinf=100),
-               info="pk.calc.cl.all is a simple wrapper around pk.calc.cl")
-  expect_equal(pk.calc.cl.obs(dose=10, aucinf.obs=100),
-               pk.calc.cl(dose=10, aucinf=100),
-               info="pk.calc.cl.obs is a simple wrapper around pk.calc.cl")
-  expect_equal(pk.calc.cl.pred(dose=10, aucinf.pred=100),
-               pk.calc.cl(dose=10, aucinf=100),
-               info="pk.calc.cl.pred is a simple wrapper around pk.calc.cl")
+               info="Vector for dose and scalar for auc scalar output with the sum of doses")
+  expect_equal(pk.calc.cl(dose=c(50, 50), auc=c(NA, 100)),
+               c(NA_real_, 0.5),
+               info="NA generation works with NA, including for a vector")
+  expect_equal(pk.calc.cl(dose=c(50, 50), auc=c(0, 100)),
+               c(NA_real_, 0.5),
+               info="NA generation works with zero, including for a vector")
 })
 
 test_that("pk.calc.f", {
-  expect_equal(pk.calc.f(1, 1, 1, 2), 2)
+  expect_equal(pk.calc.f(1, 1, 1, 2), 2,
+               info="Standard bioavailability calculation")
+  expect_equal(pk.calc.f(NA, 1, 1, 1), NA_real_,
+               info="NA handling per parameter in bioavailability (1)")
+  expect_equal(pk.calc.f(1, NA, 1, 1), NA_real_,
+               info="NA handling per parameter in bioavailability (2)")
+  expect_equal(pk.calc.f(1, 1, NA, 1), NA_real_,
+               info="NA handling per parameter in bioavailability (3)")
+  expect_equal(pk.calc.f(1, 1, 1, NA), NA_real_,
+               info="NA handling per parameter in bioavailability (4)")
+  expect_equal(pk.calc.f(0, 1, 1, 1), NA_real_,
+               info="Zero handling per parameter in bioavailability (1)")
+  expect_equal(pk.calc.f(1, 0, 1, 1), NA_real_,
+               info="Zero handling per parameter in bioavailability (2)")
+  expect_equal(pk.calc.f(1, 1, 0, 1), NA_real_,
+               info="Zero handling per parameter in bioavailability (3)")
+  expect_equal(pk.calc.f(1, 1, 1, 0), 0,
+               info="Zero handling per parameter in bioavailability (4)")
 })
 
-test_that("pk.calc.aucpext and its wrappers", {
+test_that("pk.calc.aucpext", {
   expect_equal(pk.calc.aucpext(1, 2), 50)
   expect_equal(pk.calc.aucpext(1.8, 2), 10)
-  expect_warning(v1 <- pk.calc.aucpext(2, 1))
+  expect_warning(v1 <- pk.calc.aucpext(2, 1),
+                 regexp="aucpext is typically only calculated when aucinf is greater than auclast.")
   expect_equal(v1, -100)
-  expect_warning(pk.calc.aucpext(2, 1),
-                 regexp="auclast should be less than aucinf")
-
-  expect_equal(pk.calc.aucpext.obs(1, 2),
-               pk.calc.aucpext(1, 2),
-               info="pk.calc.aucpext.obs is a simple wrapper around pk.calc.aucpext")
-  expect_equal(pk.calc.aucpext.pred(1, 2),
-               pk.calc.aucpext(1, 2),
-               info="pk.calc.aucpext.pred is a simple wrapper around pk.calc.aucpext")
+  expect_warning(v2 <- pk.calc.aucpext(auclast=0, aucinf=0),
+                 regexp="aucpext is typically only calculated when aucinf is greater than auclast.")
+  expect_equal(v2, NA_real_,
+               info="aucinf<=0 gives NA_real_ (not infinity)")
+  expect_equal(pk.calc.aucpext(NA, NA),
+               NA_real_,
+               info="Percent extrapolated is NA when both inputs are NA.")
+  expect_equal(pk.calc.aucpext(NA, 1),
+               NA_real_,
+               info="Percent extrapolated is NA when input auclast is NA.")
+  expect_equal(pk.calc.aucpext(1, NA),
+               NA_real_,
+               info="Percent extrapolated is NA when input aucinf is NA.")
+  expect_error(pk.calc.aucpext(1:2, 1:3),
+               regexp="auclast and aucinf must either be a scalar or the same length.",
+               info="aucpext input length checks require consistency.")
+  expect_equal(pk.calc.aucpext(c(1, NA), 2),
+               c(50, NA_real_),
+               info="Percent extrapolated works with vector/scalar input.")
+  expect_equal(pk.calc.aucpext(1, c(2, NA)),
+               c(50, NA_real_),
+               info="Percent extrapolated works with scalar/vector input.")
+  expect_equal(pk.calc.aucpext(c(1, 1), c(2, NA)),
+               c(50, NA_real_),
+               info="Percent extrapolated works with vector/vector input.")
 })
 
-test_that("pk.calc.mrt and its wrappers", {
-  expect_equal(pk.calc.mrt(1, 2), 2)
-  expect_equal(pk.calc.mrt.obs(1, 2),
-               pk.calc.mrt(1, 2),
-               info="pk.calc.mrt.obs is a simple wrapper around pk.calc.mrt")
-  expect_equal(pk.calc.mrt.pred(1, 2),
-               pk.calc.mrt(1, 2),
-               info="pk.calc.mrt.pred is a simple wrapper around pk.calc.mrt")
-  expect_equal(pk.calc.mrt.last(1, 2),
-               pk.calc.mrt(1, 2),
-               info="pk.calc.mrt.last is a simple wrapper around pk.calc.mrt")
+test_that("pk.calc.mrt", {
+  expect_equal(pk.calc.mrt(auc=1, aumc=2),
+               2,
+               info="MRT is calculated correctly")
 })
 
-test_that("pk.calc.vz and its wrappers", {
+test_that("pk.calc.mrt.iv", {
+  expect_equal(pk.calc.mrt.iv(auc=1, aumc=2, duration.dose=1),
+               1.5,
+               info="MRT.iv is calculated correctly")
+  expect_equal(pk.calc.mrt.iv(auc=1, aumc=2, duration.dose=0),
+               2,
+               info="MRT.iv is calculated correctly when duration is 0")
+  expect_equal(pk.calc.mrt.iv(auc=1, aumc=2, duration.dose=NA),
+               NA_real_,
+               info="MRT.iv is calculated correctly when duration is missing")
+  expect_equal(pk.calc.mrt.iv(auc=0, aumc=2, duration.dose=NA),
+               NA_real_,
+               info="MRT.iv is calculated correctly when auc is zero")
+})
+
+test_that("pk.calc.mrt.md", {
+  expect_equal(pk.calc.mrt.md(1, 2, 1.5, 24), 2 + 24*0.5)
+  expect_equal(pk.calc.mrt.md(0, 2, 1.5, 24), NA_real_,
+               info="auctau <= 0 becomes NA (not Inf)")
+})
+
+test_that("pk.calc.vz", {
   ## Ensure that cl and lambda.z are required
   expect_equal(pk.calc.vz(cl=NA, lambda.z=NA), NA_integer_)
   expect_error(pk.calc.vz(cl=NA),
@@ -276,26 +303,12 @@ test_that("pk.calc.vz and its wrappers", {
                             c(1, 2, NA, 1, 2, NA, 1, 2, NA)),
                c(1, 0.5, NA, 2, 1, NA, NA, NA, NA),
                info="Vz with vector inputs including missing values for both parameters (cl and lambda.z)")
-  
-  expect_equal(pk.calc.vz.obs(cl.obs=1, lambda.z=1),
-               pk.calc.vz(cl=1, lambda.z=1),
-               info="pk.calc.vz.obs is a simple wrapper around pk.calc.vz")
-  expect_equal(pk.calc.vz.pred(cl.pred=1, lambda.z=1),
-               pk.calc.vz(cl=1, lambda.z=1),
-               info="pk.calc.vz.pred is a simple wrapper around pk.calc.vz")
 })
 
 test_that("pk.calc.vss and its wrappers", {
   expect_equal(pk.calc.vss(1, 1), 1)
   expect_equal(pk.calc.vss(2, 1), 2)
   expect_equal(pk.calc.vss(1, 2), 2)
-  
-  expect_equal(pk.calc.vss.obs(cl.obs=1, mrt.obs=1),
-               pk.calc.vss(cl=1, mrt=1),
-               info="pk.calc.vss.obs is a simple wrapper around pk.calc.vss")
-  expect_equal(pk.calc.vss.pred(cl.pred=1, mrt.pred=1),
-               pk.calc.vss(cl=1, mrt=1),
-               info="pk.calc.vss.pred is a simple wrapper around pk.calc.vss")
 })
 
 test_that("pk.calc.vd and its wrappers", {
@@ -313,17 +326,19 @@ test_that("pk.calc.vd and its wrappers", {
   expect_equal(pk.calc.vd(c(1, 2), 2, 3), 0.5,
                info="Vd calculation works with vector dose and scalar aucinf and lambda.z inputs returning a scalar with the sum of doses used.")
   
-  expect_equal(pk.calc.vd.obs(dose=1, aucinf.obs=2, lambda.z=3),
-               pk.calc.vd(dose=1, aucinf=2, lambda.z=3),
-               info="pk.calc.vd.obs is a simple wrapper around pk.calc.vd")
-  expect_equal(pk.calc.vd.pred(dose=1, aucinf.pred=2, lambda.z=3),
-               pk.calc.vd(dose=1, aucinf=2, lambda.z=3),
-               info="pk.calc.vd.pred is a simple wrapper around pk.calc.vd")
+  expect_equal(pk.calc.vd(dose=1, aucinf=0, lambda.z=1),
+               NA_real_,
+               info="aucinf<=0 becomes NA")
+  expect_equal(pk.calc.vd(dose=1, aucinf=1, lambda.z=0),
+               NA_real_,
+               info="lambda.z<=0 becomes NA")
 })
 
 test_that("pk.calc.cav", {
   expect_equal(pk.calc.cav(2, 0, 1), 2)
-  expect_equal(pk.calc.cav(NA, 0, 1), as.numeric(NA))
+  expect_equal(pk.calc.cav(NA, 0, 1), NA_real_)
+  expect_equal(pk.calc.cav(2, 1, 1), NA_real_,
+               info="If end == start, return NA_real_")
 })
 
 test_that("pk.calc.ctrough", {
@@ -331,7 +346,7 @@ test_that("pk.calc.ctrough", {
                info="Found and it's the first time")
   expect_equal(pk.calc.ctrough(1:5, 0:4, 1), 2,
                info="Found and it's not the first time")
-  expect_equal(pk.calc.ctrough(1:5, 0:4, 1.5), NA,
+  expect_equal(pk.calc.ctrough(1:5, 0:4, 1.5), NA_real_,
                info="Not found")
   expect_error(pk.calc.ctrough(1:5, c(0, 0:3), 0),
                regexp="Time must be monotonically increasing")
@@ -340,7 +355,7 @@ test_that("pk.calc.ctrough", {
 test_that("pk.calc.ptr", {
   expect_equal(pk.calc.ptr(cmax=2, cmin=1), 2,
                info="Confirm that the ratio goes the right way")
-  expect_equal(pk.calc.ptr(2, 0), as.numeric(NA),
+  expect_equal(pk.calc.ptr(2, 0), NA_real_,
                info="Division by zero returns NA")
 })
 
@@ -349,15 +364,17 @@ test_that("pk.calc.tlag", {
                info="find the first point")
   expect_equal(pk.calc.tlag(c(0, 0, 0, 0, 1), 0:4), 3,
                info="find the next to last point")
-  expect_equal(pk.calc.tlag(c(0, 0, 0, 0, 0), 0:4), NA,
+  expect_equal(pk.calc.tlag(c(0, 0, 0, 0, 0), 0:4), NA_real_,
                info="No increase gives NA")
-  expect_equal(pk.calc.tlag(5:1, 0:4), NA,
+  expect_equal(pk.calc.tlag(5:1, 0:4), NA_real_,
                info="No increase gives NA")
 })
 
 test_that("pk.calc.deg.fluc", {
   expect_equal(pk.calc.deg.fluc(cmax=100, cmin=10, cav=45), 200,
                info="Degree of fluctuation math works")
+  expect_equal(pk.calc.deg.fluc(cmax=100, cmin=10, cav=0), NA_real_,
+               info="Degree of fluctuation returns NA when cav=0")
 })
 
 test_that("pk.calc.swing", {
@@ -365,4 +382,18 @@ test_that("pk.calc.swing", {
                info="Swing math works")
   expect_equal(pk.calc.swing(100, 0), Inf,
                info="Swing handle Ctrough=0")
+  expect_equal(pk.calc.swing(100, -1), Inf,
+               info="Swing handle Ctrough<0")
+})
+
+test_that("pk.calc.ceoi", {
+  expect_equal(pk.calc.ceoi(conc=0:5, time=0:5, duration.dose=1),
+               1,
+               info="Ceoi returns the concentration at the end of the dosing duration")
+  expect_equal(pk.calc.ceoi(conc=0:5, time=0:5, duration.dose=1.5),
+               NA_real_,
+               info="Ceoi returns NA if there is no measurement at the end of the dosing duration")
+  expect_equal(pk.calc.ceoi(conc=0:5, time=0:5, duration.dose=NA),
+               NA_real_,
+               info="Ceoi returns NA if there is no dosing duration")
 })
\ No newline at end of file
